@@ -14,4 +14,6 @@
 
 
 from tscausalinference.__version__ import __version__
-from tscausalinference.main import tscausalinference
\ No newline at end of file
+from tscausalinference.main import tscausalinference
+from tscausalinference.main import synth_dataframe
+from tscausalinference.main import sensitivity
\ No newline at end of file
