@@ -92,10 +92,7 @@ class tscausalinference:
                 n_steps = len(self.data.query(self.string_filter).index)
                 )
         
-        self.mean_shifted, self.stadisticts, self.stats_ranges, self.samples_means = bootstrap_p_value(control = self.data.query(self.string_filter).yhat, 
-                                                                                    treatment = self.data.query(self.string_filter).y, 
-                                                                                    simulations = self.simulations
-                                                                                    )
+        self.stadisticts, self.stats_ranges, self.samples_means = bootstrap_p_value(control = self.data.query(self.string_filter).yhat, treatment = self.data.query(self.string_filter).y, simulations = self.simulations)
  
     def plot_intervention(self, past_window: int = 5, back_window: int = 25, figsize=(15, 10)):
         """
@@ -201,9 +198,9 @@ class tscausalinference:
         axes[0].legend(handles=handles, loc='upper left')
 
         # Add the mean value to the right corner
-        plt.text(1.05, 0.95, f'Prob. Effect: {self.stadisticts[0]:.2f}', ha='left', va='center', transform=plt.gca().transAxes)
-        plt.text(1.05, 0.80, f'Prob. Non Effect: {self.stadisticts[1]:.2f}', ha='left', va='center', transform=plt.gca().transAxes)
-        #plt.text(1.05, 0.75, f'Prob. NonEffect: {self.stadisticts[2]:.2f}', ha='left', va='center', transform=plt.gca().transAxes)
+        plt.text(1.05, 0.95, f'P-Value: {self.stadisticts[0]:.2f}', ha='left', va='center', transform=plt.gca().transAxes)
+        plt.text(1.05, 0.80, f'FP-Rate: {self.stadisticts[1]:.2f}', ha='left', va='center', transform=plt.gca().transAxes)
+        plt.text(1.05, 0.75, f'P-NonEf: {self.stadisticts[2]:.2f}', ha='left', va='center', transform=plt.gca().transAxes)
 
         sns.histplot(self.samples_means, kde=True, ax=axes[1])
 
@@ -216,7 +213,7 @@ class tscausalinference:
         plt.axvline(self.stats_ranges[1], color='r', linestyle='--',alpha=.5,)
 
         # Add the real mean as a scatter point
-        plt.scatter(self.mean_shifted, 0, color='orange', s=600)
+        plt.scatter(data[(data.ds >= pd.to_datetime(self.intervention[0]))&(data.ds <= pd.to_datetime(self.intervention[1]))].y.mean(), 0, color='orange', s=600)
 
         # Show the plot
         sns.despine()
@@ -305,7 +302,7 @@ class tscausalinference:
                 round(data[(data.ds >= self.intervention[0]) & (data.ds <= self.intervention[1])].yhat_upper.mean(),2),
                 abs(round(self.pre_int_metrics[2][1],2)),
                 abs(round(self.int_metrics[3][1],2)),
-                (1 - round(abs(round(self.int_metrics[3][1], 2)) / abs(round(self.pre_int_metrics[2][1], 2)), 2)) * 100,
+                round(abs(round(self.int_metrics[3][1], 2)) / abs(round(self.pre_int_metrics[2][1], 2)), 2) * 100,
                 round(round(abs(self.int_metrics[3][1]),2) - abs(round(self.pre_int_metrics[2][1],2)),2),
                 self.n_samples,
                 round(self.stadisticts[0],5)
